@@ -24,10 +24,10 @@
 /*
  *      Program version:
  */
-#define PROG_VERSION            "1.0.0"
+#define PROG_VERSION            "1.3.0"
 
-#define PROG_VERSION_MAJOR      0
-#define PROG_VERSION_MINOR      9
+#define PROG_VERSION_MAJOR      1
+#define PROG_VERSION_MINOR      3
 #define PROG_VERSION_RELEASE	0
 
 
@@ -59,6 +59,8 @@ El Uso: SearchAndRescue [options] [GUI_options]\n\
                                 accelerated video cards).\n\
         --fullscreen            Utilice el modo repleto de pantalla en\n\
                                 inicio.\n\
+        --window                Start game in windowed mode.\n\
+        --no-keyrepeat          Prevent keys from sticking.\n\
         --recorder <address>    Especifica recorder la direccin.\n\
         --nosound               No conecte para sonar camarero en inicio.\n\
         --nomenubg              No demuestre men las imgenes del fondo.\n\
@@ -101,6 +103,8 @@ L'usage: SearchAndRescue [options] [GUI_options]\n\
                                 accelerated video cards).\n\
         --fullscreen            Utiliser le mode cran complet au\n\
                                 dmarrage.\n\
+        --window                Start game in windowed mode.\n\
+        --no-keyrepeat          Prevent keys from sticking.\n\
         --recorder <address>    Spcifie l'adresse de recorder.\n\
         --nosound               Ne pas connecter pour sembler le serveur\n\
                                 au dmarrage.\n\
@@ -145,6 +149,8 @@ Brauch: SearchAndRescue [options] [GUI_options]\n\
                                 redraws (slow but required for certain\n\
                                 accelerated video cards).\n\
         --fullscreen            Benutzen Sie vollen Schirm Modus an Start.\n\
+        --window                Start game in windowed mode.\n\
+        --no-keyrepeat          Prevent keys from sticking.\n\
         --recorder <address>    Gibt recorder Anschrift an.\n\
         --nosound               Verbinden Sie nicht, Diener an Start zu\n\
                                 ertnen.\n\
@@ -187,6 +193,8 @@ L'uso: SearchAndRescue [options] [GUI_options]\n\
                                 redraws (slow but required for certain\n\
                                 accelerated video cards).\n\
         --fullscreen            Usare il modo di schermo pieno all'avvio.\n\
+        --window                Start game in windowed mode.\n\
+        --no-keyrepeat          Prevent keys from sticking.\n\
         --recorder <address>    Specifica l'indirizzo di recorder.\n\
         --nosound               Non collegare per sembrare il server\n\
                                 all'avvio.\n\
@@ -231,6 +239,8 @@ Gebruik: SearchAndRescue [options] [GUI_options]\n\
                                 redraws (slow but required for certain\n\
                                 accelerated video cards).\n\
         --fullscreen            Gebruik vole scherm modus aan start.\n\
+        --window                Start game in windowed mode.\n\
+        --no-keyrepeat          Prevent keys from sticking.\n\
         --recorder <address>    Recorder adres specificeert.\n\
         --nosound               Verbind niet om kelner aan start te\n\
                                 klinken.\n\
@@ -271,6 +281,8 @@ O Uso: SearchAndRescue [options] [GUI_options]\n\
                                 redraws (slow but required for certain\n\
                                 accelerated video cards).\n\
         --fullscreen            Use pleno modo de tela em startup.\n\
+        --window                Start game in windowed mode.\n\
+        --no-keyrepeat          Prevent keys from sticking.\n\
         --recorder <address>    Especifica endereo de recorder.\n\
         --nosound               Nao ligue para soar servidor em startup.\n\
         --nomenubg              Nao exiba imagens de experincia de\n\
@@ -313,6 +325,8 @@ Praksis: SearchAndRescue [options] [GUI_options]\n\
                                 redraws (slow but required for certain\n\
                                 accelerated video cards).\n\
         --fullscreen            Bruk full skjermmodus p oppstarting.\n\
+        --window                Start game in windowed mode.\n\
+        --no-keyrepeat          Prevent keys from sticking.\n\
         --recorder <address>    Spesifiserer recorder adresse.\n\
         --nosound               Forbind ikke lyde tjener p oppstarting.\n\
         --nomenubg              Vis ikke menybakgrunnavbilder.\n\
@@ -349,6 +363,8 @@ Usage: SearchAndRescue [options] [GUI_options]\n\
                                 redraws (slow but required for certain\n\
                                 accelerated video cards).\n\
         --fullscreen            Use full screen mode at startup.\n\
+        --window                Start game in windowed mode.\n\
+        --no-keyrepeat          Prevent keys from sticking.\n\
         --recorder <address>    Specifies recorder address.\n\
         --nosound               Do not connect to sound server at startup.\n\
         --nomenubg              Do not display menu background images.\n\
@@ -1503,6 +1519,8 @@ STRUCTURE OVERSPEED FAILURE"
 #define SAR_MESG_CRASH_AIRCRAFT		"\
 *** AIRCRAFT ***"
 
+#define SAR_MESG_CRASH_FIRE             "\
+*** FIRE ***"
 
 #define SAR_MESG_FLIGHT_PHYSICS_UNSUPPORTED	"\
 Unsupported flight physics mode"
